```
Usage: vcd gateway sub-allocate-ip update [OPTIONS] <name>

Options:
  -e, --external-network <external network>
                                  external network connected to the gateway.
                                  [required]
  -o, --old-ip-range <old-ip-range>
                                  existing IP ranges used for static pool
                                  allocation in the network.  [required]
  -n, --new-ip-range <new-ip-range>
                                  new IP range to replace the existing IP
                                  range.  [required]
  -h, --help                      Show this message and exit.

```
